==> boinc-client-5.2.15.tar.bz2: boinc-client-5.2.15/clientgui/Events.h <==
// Berkeley Open Infrastructure for Network Computing
// http://boinc.berkeley.edu
// Copyright (C) 2005 University of California
//
// This is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation;
// either version 2.1 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// To view the GNU Lesser General Public License visit
// http://www.gnu.org/copyleft/lesser.html
// or write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef _EVENTS_H_
#define _EVENTS_H_

#define ID_FRAME                                6000
#define ID_STATUSBAR                            6001
#define ID_FRAMENOTEBOOK                        6002
#define ID_REFRESHSTATETIMER                    6003
#define ID_FRAMERENDERTIMER                     6004
#define ID_FRAMETASKRENDERTIMER                 6005
#define ID_FRAMELISTRENDERTIMER                 6006
#define ID_DOCUMENTPOLLTIMER                    6007
#define ID_FILEACTIVITYRUNALWAYS                6009
#define ID_FILEACTIVITYRUNBASEDONPREPERENCES    6010
#define ID_FILEACTIVITYSUSPEND                  6011
#define ID_FILENETWORKRUNALWAYS                 6012
#define ID_FILENETWORKRUNBASEDONPREPERENCES     6013
#define ID_FILENETWORKSUSPEND                   6014
#define ID_COMMADSRETRYCOMMUNICATIONS           6015
#define ID_FILERUNBENCHMARKS                    6016
#define ID_FILESELECTCOMPUTER                   6017
#define ID_PROJECTSATTACHACCOUNTMANAGER         6018
#define ID_PROJECTSATTACHPROJECT                6019
#define ID_OPTIONSOPTIONS                       6020
#define ID_HELPBOINC                            6021
#define ID_HELPBOINCMANAGER                     6022
#define ID_TB_ACTIVITYRUNALWAYS                 6023
#define ID_TB_ACTIVITYRUNBASEDONPREPERENCES     6024
#define ID_TB_ACTIVITYSUSPEND                   6025
#define ID_TB_NETWORKRUNALWAYS                  6026
#define ID_TB_NETWORKRUNBASEDONPREPERENCES      6027
#define ID_TB_NETWORKSUSPEND                    6028
#define ID_LIST_BASE                            7000
#define ID_LIST_PROJECTSVIEW                    7000
#define ID_LIST_WORKVIEW                        7001
#define ID_LIST_TRANSFERSVIEW                   7002
#define ID_LIST_MESSAGESVIEW                    7003
#define ID_LIST_RESOURCEUTILIZATIONVIEW         7004
#define ID_LIST_STATISTICSVIEW                  7005
#define ID_TASK_BASE                            8000
#define ID_TASK_PROJECTSVIEW                    8000
#define ID_TASK_WORKVIEW                        8001
#define ID_TASK_TRANSFERSVIEW                   8002
#define ID_TASK_MESSAGESVIEW                    8003
#define ID_TASK_STATISTICSVIEW                  8004
#define ID_TASK_RESOURCEUTILIZATIONVIEW         8005
#define ID_TASK_PROJECT_UPDATE                  9000
#define ID_TASK_PROJECT_SUSPEND                 9002
#define ID_TASK_PROJECT_RESUME                  9003
#define ID_TASK_PROJECT_NONEWWORK               9004
#define ID_TASK_PROJECT_ALLOWNEWWORK            9005
#define ID_TASK_PROJECT_RESET                   9006
#define ID_TASK_PROJECT_DETACH                  9007
#define ID_TASK_PROJECT_WEB_PROJDEF_MIN         9100
#define ID_TASK_PROJECT_WEB_PROJDEF_MAX         9150
#define ID_TASK_WORK_SUSPEND                    9200
#define ID_TASK_WORK_RESUME                     9201
#define ID_TASK_WORK_SHOWGRAPHICS               9202
#define ID_TASK_WORK_ABORT                      9203
#define ID_TASK_TRANSFERS_RETRYNOW              9300
#define ID_TASK_TRANSFERS_ABORT                 9301
#define ID_TASK_MESSAGES_COPYALL                9400
#define ID_TASK_MESSAGES_COPYSELECTED           9401
#define ID_TASK_STATISTICS_USERTOTAL            9500
#define ID_TASK_STATISTICS_USERAVERAGE          9501
#define ID_TASK_STATISTICS_HOSTTOTAL            9502
#define ID_TASK_STATISTICS_HOSTAVERAGE          9503


#endif

==> boinc-client-5.4.7.tar.bz2: boinc-client-5.4.7/clientgui/Events.h <==
// Berkeley Open Infrastructure for Network Computing
// http://boinc.berkeley.edu
// Copyright (C) 2005 University of California
//
// This is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation;
// either version 2.1 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// To view the GNU Lesser General Public License visit
// http://www.gnu.org/copyleft/lesser.html
// or write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef _EVENTS_H_
#define _EVENTS_H_

#define ID_FRAME                                6000
#define ID_STATUSBAR                            6001
#define ID_FRAMENOTEBOOK                        6002
#define ID_REFRESHSTATETIMER                    6003
#define ID_FRAMERENDERTIMER                     6004
#define ID_FRAMETASKRENDERTIMER                 6005
#define ID_FRAMELISTRENDERTIMER                 6006
#define ID_DOCUMENTPOLLTIMER                    6007
#define ID_FILEACTIVITYRUNALWAYS                6009
#define ID_FILEACTIVITYRUNBASEDONPREPERENCES    6010
#define ID_FILEACTIVITYSUSPEND                  6011
#define ID_FILENETWORKRUNALWAYS                 6012
#define ID_FILENETWORKRUNBASEDONPREPERENCES     6013
#define ID_FILENETWORKSUSPEND                   6014
#define ID_COMMANDSRETRYCOMMUNICATIONS          6015
#define ID_FILERUNBENCHMARKS                    6016
#define ID_FILESELECTCOMPUTER                   6017
#define ID_PROJECTSATTACHACCOUNTMANAGER         6018
#define ID_PROJECTSATTACHPROJECT                6019
#define ID_OPTIONSOPTIONS                       6020
#define ID_HELPBOINC                            6021
#define ID_HELPBOINCMANAGER                     6022
#define ID_TOOLSAMUPDATENOW                     6029
#define ID_ADVANCEDAMDEFECT                     6030
#define ID_OPENWEBSITE                          6031
#define ID_TB_TIMER                             6800
#define ID_TB_SUSPEND                           6801
#define ID_LIST_BASE                            7000
#define ID_LIST_PROJECTSVIEW                    7000
#define ID_LIST_WORKVIEW                        7001
#define ID_LIST_TRANSFERSVIEW                   7002
#define ID_LIST_MESSAGESVIEW                    7003
#define ID_LIST_RESOURCEUTILIZATIONVIEW         7004
#define ID_LIST_STATISTICSVIEW                  7005
#define ID_TASK_BASE                            8000
#define ID_TASK_PROJECTSVIEW                    8000
#define ID_TASK_WORKVIEW                        8001
#define ID_TASK_TRANSFERSVIEW                   8002
#define ID_TASK_MESSAGESVIEW                    8003
#define ID_TASK_STATISTICSVIEW                  8004
#define ID_TASK_RESOURCEUTILIZATIONVIEW         8005
#define ID_TASK_PROJECT_UPDATE                  9000
#define ID_TASK_PROJECT_SUSPEND                 9002
#define ID_TASK_PROJECT_RESUME                  9003
#define ID_TASK_PROJECT_NONEWWORK               9004
#define ID_TASK_PROJECT_ALLOWNEWWORK            9005
#define ID_TASK_PROJECT_RESET                   9006
#define ID_TASK_PROJECT_DETACH                  9007
#define ID_TASK_PROJECT_WEB_PROJDEF_MIN         9100
#define ID_TASK_PROJECT_WEB_PROJDEF_MAX         9150
#define ID_TASK_WORK_SUSPEND                    9200
#define ID_TASK_WORK_RESUME                     9201
#define ID_TASK_WORK_SHOWGRAPHICS               9202
#define ID_TASK_WORK_ABORT                      9203
#define ID_TASK_TRANSFERS_RETRYNOW              9300
#define ID_TASK_TRANSFERS_ABORT                 9301
#define ID_TASK_MESSAGES_COPYALL                9400
#define ID_TASK_MESSAGES_COPYSELECTED           9401
#define ID_TASK_STATISTICS_USERTOTAL            9500
#define ID_TASK_STATISTICS_USERAVERAGE          9501
#define ID_TASK_STATISTICS_HOSTTOTAL            9502
#define ID_TASK_STATISTICS_HOSTAVERAGE          9503
#define ID_TASK_STATISTICS_NEXTPROJECT          9601 
#define ID_TASK_STATISTICS_PREVPROJECT          9602 
#define ID_TASK_STATISTICS_MODEVIEW0            9610 
#define ID_TASK_STATISTICS_MODEVIEW1            9611 
#define ID_TASK_STATISTICS_MODEVIEW2            9612 

#endif
